@@ -29,15 +29,17 @@ def test_cli(tempdir):
     "Simple smoke test to see if it runs at all."
 
     prev_dir = os.getcwd()
-    os.chdir(tempdir)
 
-    with open('file1.txt', 'wt') as f:
-        print('Hello world', file=f)
+    try:
+        os.chdir(tempdir)
 
-    cli.entrypoint(['cabinet', 'pack', 'cabinet.wwtl', 'file1.txt'])
+        with open('file1.txt', 'wt') as f:
+            print('Hello world', file=f)
 
-    os.remove('file1.txt')
-    cli.entrypoint(['cabinet', 'unpack', 'cabinet.wwtl'])
+        cli.entrypoint(['cabinet', 'pack', 'cabinet.wwtl', 'file1.txt'])
 
-    # Windows can't remove the temp tree unless we chdir out of it.
-    os.chdir(prev_dir)
\ No newline at end of file
+        os.remove('file1.txt')
+        cli.entrypoint(['cabinet', 'unpack', 'cabinet.wwtl'])
+    finally:
+        # Windows can't remove the temp tree unless we chdir out of it.
+        os.chdir(prev_dir)
\ No newline at end of file
